pub struct CommitSubmission {
pub capsule_object_id: ObjectId,
pub capsule_digest: [u8; 32],
pub write_set_pages: Vec<PageNumber>,
pub witness_refs: Vec<ObjectId>,
pub edge_ids: Vec<ObjectId>,
pub merge_witness_ids: Vec<ObjectId>,
pub txn_token: TxnToken,
pub begin_seq: CommitSeq,
}Expand description
A commit submission from a writer to the WriteCoordinator (7.11.1 step 7).
Contains everything the coordinator needs to validate and commit the transaction without decoding the full capsule.
Fields
capsule_object_id: ObjectIdContent-addressed identity of the persisted capsule.
capsule_digest: [u8; 32]BLAKE3 digest of the capsule bytes (for coordinator validation).
write_set_pages: Vec<PageNumber>Page numbers touched by this transaction (no false negatives).
witness_refs: Vec<ObjectId>SSI witness evidence object refs.
edge_ids: Vec<ObjectId>SSI dependency edge object refs.
merge_witness_ids: Vec<ObjectId>SSI merge witness object refs.
txn_token: TxnTokenTransaction identity.
begin_seq: CommitSeqSnapshot basis (the commit_seq at BEGIN time).