pub struct ParallelWalTraceRecord {Show 14 fields
pub component: String,
pub trace_id: u64,
pub decision_id: Option<u64>,
pub mode: ParallelWalOperatingMode,
pub lane_id: Option<usize>,
pub epoch: Option<u64>,
pub commit_seq_lo: Option<CommitSeq>,
pub commit_seq_hi: Option<CommitSeq>,
pub checkpoint_epoch: Option<u64>,
pub recovery_epoch: Option<u64>,
pub fallback_active: bool,
pub fallback_reason: Option<ParallelWalFallbackReason>,
pub policy_id: Option<String>,
pub policy_version: Option<String>,
}Expand description
Trace schema shared by lane, combiner, checkpoint, recovery, and control-plane events.
Fields
component: Stringtrace_id: u64decision_id: Option<u64>mode: ParallelWalOperatingModelane_id: Option<usize>epoch: Option<u64>commit_seq_lo: Option<CommitSeq>commit_seq_hi: Option<CommitSeq>checkpoint_epoch: Option<u64>recovery_epoch: Option<u64>fallback_active: boolfallback_reason: Option<ParallelWalFallbackReason>policy_id: Option<String>policy_version: Option<String>Trait Implementations
Sourceimpl Clone for ParallelWalTraceRecord
impl Clone for ParallelWalTraceRecord
Sourcefn clone(&self) -> ParallelWalTraceRecord
fn clone(&self) -> ParallelWalTraceRecord
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ParallelWalTraceRecord
impl Debug for ParallelWalTraceRecord
impl Eq for ParallelWalTraceRecord
Sourceimpl PartialEq for ParallelWalTraceRecord
impl PartialEq for ParallelWalTraceRecord
Sourcefn eq(&self, other: &ParallelWalTraceRecord) -> bool
fn eq(&self, other: &ParallelWalTraceRecord) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ParallelWalTraceRecord